@@ -3,6 +3,7 @@ import re
 from base64 import b64encode
 from collections.abc import Hashable, Sequence
 from sys import byteorder, hash_info, stdin
+from typing import Dict, Optional, Union
 
 SEVERITY = {
     "note": "info",
@@ -14,7 +15,7 @@ def get_hash(tpl: Sequence[Hashable]) -> str:
     return b64encode(hash(tpl).to_bytes(hash_info.width // 8, byteorder, signed=True)).decode()
 
 
-def parse_line(line: str) -> dict[str, str | dict[str, str | dict[str, int]]] | None:
+def parse_line(line: str) -> Optional[Dict[str, Union[str, Dict[str, Union[str, Dict[str, int]]]]]]:
     match = re.fullmatch(r"(?P<path>.+?):(?P<line>\d+):(?:\d+:)?\s(?P<error_level>\w+):\s(?P<description>.+)", line)
     if match is None:
         return None
